@@ -15,6 +15,7 @@ renderBarChart <- function(div_id,
                            rotate.axis.x = 0, rotate.axis.y = 0,
                            bar.max.width = NULL,
                            animation = TRUE,
+                           hyperlinks = NULL,
                            running_in_shiny = TRUE){
 
   data <- isolate(data)
@@ -38,6 +39,12 @@ renderBarChart <- function(div_id,
     }
   }
 
+
+  # Check if the length of "hyperlink" is the same as the length of the x-axis names
+  if((length(hyperlinks) != dim(data)[1]) & (is.null(hyperlinks) == FALSE)){
+    stop("The length of 'hyperlinks' should be the same as the number of observations (the number of rows of the data).")
+  }
+
   xaxis_name <- paste(sapply(row.names(data), function(x){paste("'", x, "'", sep="")}), collapse=", ")
   xaxis_name <- paste("[", xaxis_name, "]", sep="")
   legend_name <- paste(sapply(names(data), function(x){paste("'", x, "'", sep="")}), collapse=", ")
@@ -75,7 +82,11 @@ renderBarChart <- function(div_id,
                         ");",
 
                         "option_", div_id,
-                        " = {tooltip : {trigger:'axis', axisPointer:{type:'shadow'}}, ",
+                        " = {tooltip : {trigger:'axis', axisPointer:{type:'shadow'}",
+                        ifelse(is.null(hyperlinks),
+                               "",
+                               ", textStyle:{fontStyle:'italic', color:'skyblue'}"),
+                        "}, ",
 
                         ifelse(show.tools,
                                "toolbox:{feature:{magicType:{type: ['stack', 'tiled']}, saveAsImage:{}}}, ",
@@ -111,6 +122,25 @@ renderBarChart <- function(div_id,
                         div_id, ".resize()",
                         "});",
 
+                        ifelse(is.null(hyperlinks),
+                               "",
+                               paste(div_id,
+                                    ".on('click', function (param){
+                                    var name=param.name;",
+
+                                     paste(sapply(1:length(hyperlinks),
+                                                  function(i){
+                                                    paste("if(name=='", row.names(data)[i], "'){",
+                                                          "window.location.href='", hyperlinks[i], "';}",
+                                                          sep="")
+                                                  }),
+                                           collapse = ""),
+
+                                "});",
+                                div_id, ".on('click');",
+                                sep="")
+                               ),
+
                         sep="")
 
   to_eval <- paste("output$", div_id ," <- renderUI({fluidPage(tags$script(\"",
